<?php
/**
 * @copyright	Copyright (c) 2013 Skyline Software (http://extstore.com). All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

// no direct access
defined('_JEXEC') or die();

jimport('joomla.plugin.plugin');

/**
 * System - Script Remover Plugin
 *
 * @package		Joomla.Plugin
 * @subpakage	Skyline.ScriptRemover
 */
class plgSystemSL_ScriptRemover extends JPlugin {

	/**
	 * Constructor.
	 *
	 * @param 	$subject
	 * @param	array $config
	 */
	function __construct(&$subject, $config = array()) {
		// call parent constructor
		parent::__construct($subject, $config);
	}

	/**
	 * onBeforeRender hook.
	 */
	public function onBeforeRender() {
		$load_jquery	= $this->params->get('load_jquery');

		if (!$load_jquery) {
			return;
		}

		$document	= JFactory::getDocument();
		$scripts	= $document->_scripts;
		$val		= array(
			'mime'		=> 'text/javascript',
			'defer'		=> false,
			'async'		=> false,
		);
		$array		= array();
		$found		= false;
		$app		= JFactory::getApplication();
		$jquery		= JURI::root(true) . '/plugins/system/sl_scriptremover/assets/' . ($app->getCfg('debug') ? 'jquery.js' : 'jquery.min.js');

		foreach ($scripts as $key => $value) {
			if (strpos($key, 'mootools-core') === false) {
				$array[$key]	= $value;
			} else {
				if ($load_jquery == '-1') {
					$array[$jquery] = $val;
					$array[$key]	= $value;
				} else {
					$array[$key]	= $value;
					$array[$jquery] = $val;
					$document->addScriptDeclaration('jQuery.noConflict();');
				}
			}
		}

		if (!$found) {
			$array[$jquery] = $val;
		}

		$document->_scripts	= $array;
	}

	/**
	 * onAfterRender hook.
	 */
	public function onAfterRender() {
		$files		= trim($this->params->get('files'));
		$commands	= trim($this->params->get('commands'));

		if (!$files && !$commands) {
			return;
		}

		$body		= JResponse::getBody();

		// process files
		if ($files) {
			$files	= explode("\n", $files);

			foreach ($files as $file) {
				$regex	= '|<script[^>]*'. preg_quote(trim($file), '|') . '[^<]*</script>|s';
				$body	= preg_replace($regex, '', $body);
			}
		}

		// process commands
		if ($commands) {
			$commands = explode("|*|", $commands);
			$app	= JFactory::getApplication();
			$db		= JFactory::getDbo();
			$query	= 'SELECT extension_id'
					. ' FROM #__extensions'
					. ' WHERE type = \'plugin\' AND folder = \'system\' AND element = ' . $db->quote($db->escape($this->_name));
			$db->setQuery($query);
			$id		= $db->loadResult();

			if ($app->isAdmin() && JRequest::getVar('option') == 'com_plugins' && JRequest::getVar('extension_id') == $id) {
				return;
			}

			foreach ($commands as $command) {
				$body	= str_replace($command, '', $body);
			}
		}

		JResponse::setBody($body);
	}
}